| Portability | portable |
|---|---|
| Stability | provisional |
| Maintainer | Antoine Latter <aslatter@gmail.com> |
Data.XCB
Description
The Data.XCB module can parse the contents of the xcb-proto
XML files into Haskell data structures.
Pretty-printers are provided to aid in the debugging - they do not pretty-print to XML, but to a custom human-readable format.